@@ -20,7 +20,7 @@ use strict;
 use vars qw($VERSION);
 use Image::ExifTool qw(:DataAccess :Utils);
 
-$VERSION = '1.15';
+$VERSION = '1.17';
 
 # road map of directory locations in GIF images
 my %gifMap = (
@@ -42,7 +42,7 @@ my %gifMap = (
     Comment    => {
         # for documentation only -- flag as writable for the docs, but
         # it won't appear in the TagLookup because there is no WRITE_PROC
-        Writable => 1,
+        Writable => 2,
     },
     Duration   => {
         Notes => 'duration of a single animation iteration',
@@ -67,12 +67,12 @@ my %gifMap = (
     'XMP Data/XMP' => { #2
         Name => 'XMP',
         IncludeLengthBytes => 1, # length bytes are included in the data
-        Writable => 1,
+        Writable => 2,
         SubDirectory => { TagTable => 'Image::ExifTool::XMP::Main' },
     },
     'ICCRGBG1/012' => { #4
         Name => 'ICC_Profile',
-        Writable => 1,
+        Writable => 2,
         SubDirectory => { TagTable => 'Image::ExifTool::ICC_Profile::Main' },
     },
     'MIDICTRL/Jon' => { #5
@@ -102,12 +102,12 @@ my %gifMap = (
     4.1 => {
         Name => 'HasColorMap',
         Mask => 0x80,
-        PrintConv => { 0x00 => 'No', 0x80 => 'Yes' },
+        PrintConv => { 0 => 'No', 1 => 'Yes' },
     },
     4.2 => {
         Name => 'ColorResolutionDepth',
         Mask => 0x70,
-        ValueConv => '($val >> 4) + 1',
+        ValueConv => '$val + 1',
     },
     4.3 => {
         Name => 'BitsPerPixel',
@@ -532,7 +532,7 @@ write GIF meta information.
 
 =head1 AUTHOR
 
-Copyright 2003-2018, Phil Harvey (phil at owl.phy.queensu.ca)
+Copyright 2003-2019, Phil Harvey (phil at owl.phy.queensu.ca)
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
